# The Goblin Cave

## Character Stats

- STR: 16 (+3)
- DEX: 14 (+2)
- CON: 12 (+1)
- INT: 10 (+0)
- WIS: 13 (+1)
- CHA: 8 (-1)

## Adventure Description

You enter a dark cave. The smell of rotting flesh fills your nostrils. Make a WIS saving throw DC 13 or become poisoned.

Once your eyes adjust to the darkness, you see Angry Knife, the goblin, who attacks you! Roll for initiative, using your DEX modifier.
